==> vertigo-dynamo-impl-0.7.2.jar: io/vertigo/dynamo/impl/task/TaskManagerImpl.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.impl.task;

import io.vertigo.core.Home;
import io.vertigo.core.di.injector.Injector;
import io.vertigo.dynamo.impl.task.listener.TaskListener;
import io.vertigo.dynamo.impl.task.listener.TaskListenerImpl;
import io.vertigo.dynamo.task.TaskManager;
import io.vertigo.dynamo.task.model.Task;
import io.vertigo.dynamo.task.model.TaskEngine;
import io.vertigo.dynamo.task.model.TaskResult;

/**
 * @author  pchretien
 */
public final class TaskManagerImpl implements TaskManager {
	private final TaskListener taskListener;

	public TaskManagerImpl() {
		this.taskListener = new TaskListenerImpl();
	}

	/** {@inheritDoc} */
	@Override
	public TaskResult execute(final Task task) {
		taskListener.onStart(task.getDefinition().getName());
		boolean executed = false;
		final long start = System.currentTimeMillis();
		try {
			final TaskEngine taskEngine = Injector.newInstance(task.getDefinition().getTaskEngineClass(), Home.getComponentSpace());
			final TaskResult taskResult = taskEngine.process(task);
			executed = true;
			return taskResult;
		} finally {
			taskListener.onFinish(task.getDefinition().getName(), System.currentTimeMillis() - start, executed);
		}
	}
}

==> vertigo-dynamo-impl-0.8.3.jar: io/vertigo/dynamo/impl/task/TaskManagerImpl.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.impl.task;

import io.vertigo.core.Home;
import io.vertigo.core.component.di.injector.Injector;
import io.vertigo.dynamo.impl.task.listener.TaskListener;
import io.vertigo.dynamo.impl.task.listener.TaskListenerImpl;
import io.vertigo.dynamo.task.TaskManager;
import io.vertigo.dynamo.task.model.Task;
import io.vertigo.dynamo.task.model.TaskEngine;
import io.vertigo.dynamo.task.model.TaskResult;

/**
 * @author  pchretien
 */
public final class TaskManagerImpl implements TaskManager {
	private final TaskListener taskListener;

	public TaskManagerImpl() {
		this.taskListener = new TaskListenerImpl();
	}

	/** {@inheritDoc} */
	@Override
	public TaskResult execute(final Task task) {
		taskListener.onStart(task.getDefinition().getName());
		boolean executed = false;
		final long start = System.currentTimeMillis();
		try {
			final TaskEngine taskEngine = Injector.newInstance(task.getDefinition().getTaskEngineClass(), Home.getComponentSpace());
			final TaskResult taskResult = taskEngine.process(task);
			executed = true;
			return taskResult;
		} finally {
			taskListener.onFinish(task.getDefinition().getName(), System.currentTimeMillis() - start, executed);
		}
	}
}
